pyMez.Code.Analysis API documentation
Description: The Analysis subpackage contains modules designed to change the content of objects created using a M...

Top

# pyMez.Code.Analysis module

The Analysis subpackage contains modules designed to change the content of objects created using a Model. For instance, a function that interpolates data from a table and returns a new table would live in Analysis/Interpolation.py . If a function or class is designed to only change the format of an object and not its content it should reside in DataHandlers. Any module in the Analysis subpackage can import from DataHandlers, Utils or third party libraries, however should not import from FrontEnds or Instrument control.

## Examples

How to calrep a raw data file

## Import Structure

Analysis typically import from Utils and DataHandlers but NOT from InstrumentControl or FrontEnds

## Help

`pyMez.Code`

Documentation Home | API Documentation Home | Examples | Index

Show source ≡

    """
    The Analysis subpackage contains modules designed to change the content of objects created using a Model. For instance,
    a function that interpolates data from a table and returns a new table would live in Analysis/Interpolation.py . If
    a function or class is designed to only change the format of an object and not its content it should reside
    in DataHandlers. Any module in the Analysis subpackage can import from DataHandlers, Utils or third party libraries,
     however should not import from FrontEnds or Instrument control.

     Examples
    --------
    <a href="../../../Examples/How_to_Calrep.html"> How to calrep a raw data file</a>

    Import Structure
    ----------------
    Analysis typically import from Utils and DataHandlers but __NOT__ from  InstrumentControl or FrontEnds

    Help
    -----
    <a href="../index.html">`pyMez.Code`</a>
    <div>
    <a href="../../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../../index.html">API Documentation Home</a> |
    <a href="../../../Examples/html/Examples_Home.html">Examples</a> |
    <a href="../../../Reference_Index.html">Index </a>
    </div>
    """

## Sub-modules

pyMez.Code.Analysis.Fitting

Fitting is a module containing classes and functions for fitting and simulating data.

## Examples

    >>line=FunctionalModel(variables='x',parameters='m b',equation='m*x+b')
    >>line(m=2,b=5,x=np.array([1,2,3]))

### Fitt...

pyMez.Code.Analysis.GeneralAnalysis

GeneralAnalysis is a module containing classes and functions for general analytic tasks.

## Examples

## Requirements

- sys
- os
- re
- [types](h...

pyMez.Code.Analysis.Interpolation

Interpolation holds classes and functions important for interpolating data.

## Examples

    >>test_interpolate()

### Interpolation Example

## Requirements

- [sys](https://docs.python.org/2/library...

pyMez.Code.Analysis.NISTUncertainty

This module contains definitions for uncertainty analysis for NIST sparameter impedance. It follows uncertainty equations originally found in the calrep hp basic program, and is primarily used in the function calrep see also SParameter.

## Requirements

...

pyMez.Code.Analysis.ProgramAnalysis

This module contains definitions for Analyzing Code. In particular, it has functions to generate black box diagrams of functions or scripts in svg for help support

## Requirements

- sys
- os
- [re]...

pyMez.Code.Analysis.Reports

Reports is a module dedicated to generating reports after data collection or analysis. It contains models for basic html reports and the checkstandard reporting process.

## Examples

## Requirements

- sys
- [os](https://d...

pyMez.Code.Analysis.SParameter

Sparameter is a module with tools for analyzing Scattering parameter data. It contains functions for comparing, applying corrections, uncertainty analysis and plotting scattering parameters. see also NISTUncertainty

## Examples

    >>test...

pyMez.Code.Analysis.Transformations

Transformations is a module with tools for changing data from one format to another, while not preserving the content. It complements pyMez.Code.DataHandlers.Translations, and can be added as jumps to graph models.

## Examples

## Requirements

- [sys](https://docs....

pyMez.Code.Analysis.Uncertainty

Uncertainty is a collection of general classes and functions that pertain to uncertainty calculations. For specific uncertainty calculations look for modules with a modifier in the name such as NISTUncertainty.

## Examples

    >>test_standard_error()

### <a href="../../../E...